# BITalino (r)evolution Python API

The BITalino (r)evolution Python API provides the needed tools to interact with BITalino (r)evolution using Python.

## Dependencies

- [Python3.7 +](https://www.python.org/downloads/)
- [NumPy](https://github.com/numpy/numpy)
- [pySerial](https://github.com/pyserial/pyserial)
- [PyBluez](https://github.com/pybluez/pybluez) (Not needed for macOS)

## Installation

Install [**bitalino**](https://pypi.org/project/bitalino/) API package from PyPI:

```winbatch
pip install bitalino
```

Or clone this repository and install using pip:

```winbatch
git clone https://github.com/BITalinoWorld/revolution-python-api.git
cd revolution-python-api
pip install .
```

## Documentation

<http://bitalino.com/pyAPI/>

## Example

A sample script is available at [**samples**](samples) folder.

## License

This project is licensed under the [GNU GPL v3](LICENSE.md)
